@@ -7,11 +7,14 @@
 #     PyTorch
 # Attention:
 #     1. Nothing
-import torch.nn
-from ..quant_base import QuantBase
+import torch.nn as nn
+from .quant_base import QuantBase
 
 
 class QuantLinear(QuantBase):
-    def __init__(self, name, module, bit_width, logger):
-        super().__init__(name, module, bit_width, logger)
+    def __init__(self, name, module, bit_width, logger, writer):
+        super().__init__(name, module, bit_width, logger, writer)
         self.activation_positive = False
+
+
+linear_switch = {nn.Linear: QuantLinear}
